series_bindings.generate_computes_module()
Generate a standalone module fragment with output compute functions.
Usage
series_bindings.generate_computes_module(
graph,
workbook,
bindings,
)Generate a standalone module fragment with output compute functions.
Usage