DependencyGraph.get_edge_attrs()
Return a typed snapshot of the attributes on edge from_key -> to_key.
Usage
DependencyGraph.get_edge_attrs(
from_key,
to_key,
)When the edge does not exist, returns an EdgeAttrs with all fields set to None.