exporter.ProjectionResult
Projected graph facade with durable lineage back to the canonical graph.
Usage
exporter.ProjectionResult()Parameter Attributes
original_graph: DependencyGraphprojected_graph: DependencyGraphmanifest: ProjectionManifest
Methods
| Name | Description |
|---|---|
| map_to_projected() | Map a canonical workbook address to its projected computation address. |
| target_keys() | Return target-marked addresses from the canonical workbook graph. |
map_to_projected()
Map a canonical workbook address to its projected computation address.
Usage
map_to_projected(address)target_keys()
Return target-marked addresses from the canonical workbook graph.
Usage
target_keys()